Changelog
=========

0.1.9
-----

- Ignore those weird genshi headers. `f594e5a7a <https://github.com/ralphbean/sieve/commit/f594e5a7a69fee0cc68508c5c619d65bd79da541>`_
- More loose with xml. `9133f5b0c <https://github.com/ralphbean/sieve/commit/9133f5b0c71670bf7bfe371eac09f7e48df6a871>`_
- Require markupsafe. `986dab0f9 <https://github.com/ralphbean/sieve/commit/986dab0f98b45c5669422a6d0bbc2174aeb01477>`_
- Include a changelog. `f84c9cde8 <https://github.com/ralphbean/sieve/commit/f84c9cde8c19c64e7ba09bf523528dbcb1bc3e42>`_
- Bring it inline. `70fb09687 <https://github.com/ralphbean/sieve/commit/70fb0968769d188eeb5572bda3f60c9404a2a0e1>`_

0.1.8
-----

- Fixes for tw2.forms. `93edeb487 <https://github.com/ralphbean/sieve/commit/93edeb487abb7ac04ea941e9fd6596cdf68967ee>`_
- Add py3.3 to the travis config. `a4c536992 <https://github.com/ralphbean/sieve/commit/a4c5369926bf6a1dd71a3b2af3e56baa35a01347>`_
